GOOF----LE-8-2.0M      ]< 4  h      ] g  guile	 	g  define-module*	 	 	g  rnrs	g  
arithmetic	g  fixnums		 	
g  filenameS	f  rnrs/arithmetic/fixnums.scm	g  pureS	
g  versionS		 	g  set-current-module	 	 	g  resolve-r6rs-interface	 	 	g  only	g  ash	g  cons*	g  define-inlinable	g  inexact->exact	g  logand	g  logbit?	g  logcount	g  logior	g  lognot	g  logxor	 g  most-positive-fixnum	!g  most-negative-fixnum	"g  object-address	# !" 	$g  call-with-deferred-observers	%$ 	&$ 	'g  module-use-interfaces!	(' 	)' 	*g  current-module	+* 	,* 	-g  ice-9	.g  optargs	/-. 	0g  base	10 	2g  control	32 	4g  bitwise	54 	6g  
conditions	76 	8g  
exceptions	98 	:g  lists	;: 	<g  module-export!	=< 	>< 	?g  fxreverse-bit-field	@g  fxrotate-bit-field	Ag  fxarithmetic-shift-right	Bg  fxarithmetic-shift-left	Cg  fxarithmetic-shift	Dg  fxcopy-bit-field	Eg  fxbit-field	Fg  
fxcopy-bit	Gg  
fxbit-set?	Hg  fxfirst-bit-set	Ig  fxlength	Jg  fxbit-count	Kg  fxif	Lg  fxxor	Mg  fxior	Ng  fxand	Og  fxnot	Pg  	fx*/carry	Qg  	fx-/carry	Rg  	fx+/carry	Sg  fxmod0	Tg  fxdiv0	Ug  fxdiv0-and-mod0	Vg  fxmod	Wg  fxdiv	Xg  
fxdiv-and-mod	Yg  fx-	Zg  fx*	[g  fx+	\g  fxmin	]g  fxmax	^g  fxeven?	_g  fxodd?	`g  fxnegative?	ag  fxpositive?	bg  fxzero?	cg  fx<=?	dg  fx>=?	eg  fx<?	fg  fx>?	gg  fx=?	hg  greatest-fixnum	ig  least-fixnum	jg  fixnum-width	kg  fixnum?	l?@ABCDEFGHIJKLMNOPQRSTUVWXYZ[\]^_`abcdefghijk -	mg  module-re-export!	nm 	om 	pg  module-replace!	qp 	rp 	sg  % inline-fixnum?-procedure	tg  make-syntax-transformer	ut 	vt 	wg  inline-fixnum?	xg  macro	yg  $sc-dispatch	zy 	{y 	|g  _	}g  any	~|} 	g  
syntax-object g  syntax-parameterize g  m-qh9svtEYy3Nm$9dYSIg04r-1510 g  top   g  ribcage g  t-1509     f  l-qh9svtEYy3Nm$9dYSIg04r-1515       g  x   f  l-qh9svtEYy3Nm$9dYSIg04r-1512     g  shift g  	proc-name g  args       f  l-RJ$rxRwEKVaPeeqB2SIw08-121656 f  l-RJ$rxRwEKVaPeeqB2SIw08-121657     g  name g  formals g  body     f  l-RJ$rxRwEKVaPeeqB2SIw08-121647 f  l-RJ$rxRwEKVaPeeqB2SIw08-121648 f  l-RJ$rxRwEKVaPeeqB2SIw08-121649     g  make-procedure-name g  prefix     f  l-RJ$rxRwEKVaPeeqB2SIw08-121635 f  l-RJ$rxRwEKVaPeeqB2SIw08-121633       f  l-RJ$rxRwEKVaPeeqB2SIw08-121632      
 g  hygiene       g  private   w  g  identifier-syntax   s        g  lambda   g  obj     g  not   g  =   
    	  "              g  each-any |Ҍ g  syntax-violation     f  Wrong number of arguments f  -source expression failed to match any pattern g  identifier?       s  g  
assert-fixnum }Ҍ g  or g  dummy g  arg   g  m-qh9svtEYy3Nm$9dYSIg04r-1521     f  l-qh9svtEYy3Nm$9dYSIg04r-1526 f  l-qh9svtEYy3Nm$9dYSIg04r-1527       f  l-qh9svtEYy3Nm$9dYSIg04r-1523         g  and   g  map     w  g  raise   g  make-assertion-violation         g  for-all g  assert-fixnums g  define-fxop*}}} g  defineg  op g  m-qh9svtEYy3Nm$9dYSIg04r-1531  f  l-qh9svtEYy3Nm$9dYSIg04r-1536	f  l-qh9svtEYy3Nm$9dYSIg04r-1537
f  l-qh9svtEYy3Nm$9dYSIg04r-1538	
  
 f  l-qh9svtEYy3Nm$9dYSIg04r-1533 
   g  case-lambda  g  y       g  apply   !g  >"g  <#g  >=$g  <=%g  zero?&g  	positive?'g  	negative?(g  odd?)g  even?*g  max+g  min,g  )make-implementation-restriction-violation-g  div.g  mod/g  div-and-mod0g  div01g  mod02g  
div0-and-mod03g  expt4g  
bitwise-if5g  bitwise-length6g  bitwise-first-bit-set7g  bitwise-copy-bit8g  bitwise-bit-field9g  bitwise-copy-bit-field:g  bitwise-rotate-bit-field;g  bitwise-reverse-bit-fieldC 5       h3    ]4	

5 4 >  "  G   4#5 4&), h   M   ] 45 L  6E       g  filenamef  rnrs/arithmetic/fixnums.scm
	
 		
   C O >  "  G   4/5 4&),  h   M   ] 45 L  6E       g  filenamef  rnrs/arithmetic/fixnums.scm
	
 		
   C O >  "  G   415 4&),  h   M   ] 45 L  6E       g  filenamef  rnrs/arithmetic/fixnums.scm
	
 		
   C O >  "  G   435 4&),  h   M   ] 45 L  6E       g  filenamef  rnrs/arithmetic/fixnums.scm
	
 		
   C O >  "  G   455 4&),  h   M   ] 45 L  6E       g  filenamef  rnrs/arithmetic/fixnums.scm
	
 		
   C O >  "  G   475 4&),  h   M   ] 45 L  6E       g  filenamef  rnrs/arithmetic/fixnums.scm
	
 		
   C O >  "  G   495 4&),  h   M   ] 45 L  6E       g  filenamef  rnrs/arithmetic/fixnums.scm
	
 		
   C O >  "  G   4;5 4&),  h   M   ] 45 L  6E       g  filenamef  rnrs/arithmetic/fixnums.scm
	
 		
   C O >  "  G   4&>,l h   M   ] 45 6   E       g  filenamef  rnrs/arithmetic/fixnums.scm
	
 		
   C>  "  G  4&o,   h   M   ] 45 6    E       g  filenamef  rnrs/arithmetic/fixnums.scm
	
 		
   C>  "  G  4&r,   h   M   ] 45 6    E       g  filenamef  rnrs/arithmetic/fixnums.scm
	
 		
   C>  "  G  "  " i$   "   	 "
 "   h      ] L C          		
   C O  jR       h   j   ] C   b       g  filenamef  rnrs/arithmetic/fixnums.scm
	h	 		
  g  nameg  greatest-fixnum ChR!     h   g   ] C   _       g  filenamef  rnrs/arithmetic/fixnums.scm
	i	 		
  g  nameg  least-fixnum CiR"        h   t   ]
	4 5Cl       g  obj
		  g  filenamef  rnrs/arithmetic/fixnums.scm
	k	 		  g  nameg  fixnum? CkR"   h      ]
	4 5C       g  obj
		  g  filenamef  rnrs/arithmetic/fixnums.scm
	n	 		  g  nameg  % inline-fixnum?-procedure CsR4vwx{~    h   .   ]  C      &       g  t-1509
		
  		
   Cw      h   _   ]L 6    W       g  a
		  g  filenamef  rnrs/arithmetic/fixnums.scm		n	 		   C|     h   O   ] L 6G       g  filenamef  rnrs/arithmetic/fixnums.scm		n	 		
   C   h      ] C          		
   C    hx      ]4 5$  @4 5$   O @4 5"  	 6$  4	 O ?$  
@""              g  x
		q g  tmp		q g  tmp		"	q g  tmp		>	q  g  filenamef  rnrs/arithmetic/fixnums.scm
	n	 		q   C5wR4vx{  h   0   ]  C      (       g  tmp-1530
		
  		
   C   h   >   ]45C   6       g  dummy
		 g  arg		  			   C   h(   x   ]	4 5$  @ 6      p       g  x
		" g  tmp		"  		"  g  
macro-typeg  syntax-rulesg  patternsg  argg  ...   C5Rs       h       ]	4 5$  C45 6        g  args
		 g  t		  g  filenamef  rnrs/arithmetic/fixnums.scm
	w	 		  g  nameg  assert-fixnums CR4v x{  	h0   O   ]    C      G       g  dummy
		* g  name		* g  op			*  		*	   C  h(   x   ]	4 5$  @ 6      p       g  x
		" g  tmp		"  		"  g  
macro-typeg  syntax-rulesg  patternsg  nameg  op   C5 RigR!ifR"ieR#idR$icR%ibR&iaR'i`R(i_R)i^R"*    hx      )   Q3 
	4 5$  "  
	45$  "  445 >  "  G   6-  1  3 4 >  "  G   @       g  x
			W g  y			W g  t		+	O g  args
	`	x  g  filenamef  rnrs/arithmetic/fixnums.scm
 	 			W	 	`	x


  g  nameg  fxmax C]R"+    hx      )   Q3 
	4 5$  "  
	45$  "  445 >  "  G   6-  1  3 4 >  "  G   @       g  x
			W g  y			W g  t		+	O g  args
	`	x  g  filenamef  rnrs/arithmetic/fixnums.scm
 	 			W	 	`	x


  g  nameg  fxmin C\R",      h      ]
	4 5$  "  
	45$  "  445 >  "  G   
	45$  "  445 >  "  G  C            g  fx1
	  g  fx2	  g  t		$	H g  r		M  g  t		\   g  filenamef  rnrs/arithmetic/fixnums.scm
 	 	 	  g  nameg  fx+ C[R",    h      ]
	4 5$  "  
	45$  "  445 >  "  G   
	45$  "  445 >  "  G  C            g  fx1
	  g  fx2	  g  t		$	H g  r		M  g  t		\   g  filenamef  rnrs/arithmetic/fixnums.scm
 	 	 	  g  nameg  fx* CZR"       h      - . , 3 #  
	4 5$  "  445 >  "  G  $  l
	45$  "  445 >  "  G   
	45$  "  445 >  "  G  C
 
	45$  "  445 >  "  G  C             g  fx1
	  g  fx2	  g  t		"	F g  t		Y	} g  r	   g  t	   g  r	   g  t	    g  filenamef  rnrs/arithmetic/fixnums.scm
 	 	   g  nameg  fx- CYR"- hP      ]

	4 5$  "  
	45$  "  445 >  "  G   6       g  fx1
		P g  fx2		P g  t		$	H  g  filenamef  rnrs/arithmetic/fixnums.scm
 	 		P	  g  nameg  fxdiv CWR".     hP      ]

	4 5$  "  
	45$  "  445 >  "  G   6       g  fx1
		P g  fx2		P g  t		$	H  g  filenamef  rnrs/arithmetic/fixnums.scm
 	 		P	  g  nameg  fxmod CVR"/     hP      ]

	4 5$  "  
	45$  "  445 >  "  G   6       g  fx1
		P g  fx2		P g  t		$	H  g  filenamef  rnrs/arithmetic/fixnums.scm
 	 		P	  g  nameg  
fxdiv-and-mod CXR"0     hP      ]

	4 5$  "  
	45$  "  445 >  "  G   6       g  fx1
		P g  fx2		P g  t		$	H  g  filenamef  rnrs/arithmetic/fixnums.scm
 	 		P	  g  nameg  fxdiv0 CTR"1    hP      ]

	4 5$  "  
	45$  "  445 >  "  G   6       g  fx1
		P g  fx2		P g  t		$	H  g  filenamef  rnrs/arithmetic/fixnums.scm
 	 		P	  g  nameg  fxmod0 CSR"2    hP      ]

	4 5$  "  
	45$  "  445 >  "  G   6       g  fx1
		P g  fx2		P g  t		$	H  g  filenamef  rnrs/arithmetic/fixnums.scm
 	 		P	  g  nameg  fxdiv0-and-mod0 CUR"13j0   h      ]
	4 5$  "  "
	45$  "  
	45$  "  445 >  "  G   44	45 5544	45 55D        g  fx1
	  g  fx2	  g  fx3		  g  t		9	] g  s		e  g  s0		z  g  s1	    g  filenamef  rnrs/arithmetic/fixnums.scm
 	 	 	  g  nameg  	fx+/carry CRR"13j0 h      ]
	4 5$  "  "
	45$  "  
	45$  "  445 >  "  G   44	45 5544	45 55D        g  fx1
	  g  fx2	  g  fx3		  g  t		9	] g  d		e  g  d0		z  g  d1	    g  filenamef  rnrs/arithmetic/fixnums.scm
 	 	 	  g  nameg  	fx-/carry CQR"13j0 h      ]
	4 5$  "  "
	45$  "  
	45$  "  445 >  "  G   44	45 5544	45 55D        g  fx1
	  g  fx2	  g  fx3		  g  t		9	] g  s		e  g  s0		z  g  s1	    g  filenamef  rnrs/arithmetic/fixnums.scm
 	 	 	  g  nameg  	fx*/carry CPR"  h@      ]	
	4 5$  "  445 >  "  G   6       x       g  fx
		9 g  t		3  g  filenamef  rnrs/arithmetic/fixnums.scm
 	 		9  g  nameg  fxnot COR"       hx      )   O3 
	4 5$  "  
	45$  "  445 >  "  G   C-  1  3 4 >  "  G   @         g  x
			U g  y			U g  t		+	O g  args
	^	v  g  filenamef  rnrs/arithmetic/fixnums.scm
 	 			U	 	^	v


  g  nameg  fxand CNR"     hx      )   O3 
	4 5$  "  
	45$  "  445 >  "  G   C-  1  3 4 >  "  G   @         g  x
			U g  y			U g  t		+	O g  args
	^	v  g  filenamef  rnrs/arithmetic/fixnums.scm
 	 			U	 	^	v


  g  nameg  fxior CMR"     hx      )   O3 
	4 5$  "  
	45$  "  445 >  "  G   C-  1  3 4 >  "  G   @         g  x
			U g  y			U g  t		+	O g  args
	^	v  g  filenamef  rnrs/arithmetic/fixnums.scm
 	 			U	 	^	v


  g  nameg  fxxor CLR"4      hh      ]
	4 5$  "  "
	45$  "  
	45$  "  445 >  "  G   6        g  fx1
		g g  fx2		g g  fx3			g g  t		9	]  g  filenamef  rnrs/arithmetic/fixnums.scm
 	 		g	  g  nameg  fxif CKR"    hP      ]	
	4 5$  "  445 >  "  G   
$  4 56 6    ~       g  fx
		L g  t		3  g  filenamef  rnrs/arithmetic/fixnums.scm
 	 		L  g  nameg  fxbit-count CJR"5  h@      ]	
	4 5$  "  445 >  "  G   6       {       g  fx
		9 g  t		3  g  filenamef  rnrs/arithmetic/fixnums.scm
 	 		9  g  nameg  fxlength CIR"6     h@      ]	
	4 5$  "  445 >  "  G   6              g  fx
		9 g  t		3  g  filenamef  rnrs/arithmetic/fixnums.scm
 	 		9  g  nameg  fxfirst-bit-set CHR"       hP      ]

	4 5$  "  
	45$  "  445 >  "  G   6       g  fx1
		P g  fx2		P g  t		$	H  g  filenamef  rnrs/arithmetic/fixnums.scm
 	 		P	  g  nameg  
fxbit-set? CGR"7        hh      ]
	4 5$  "  "
	45$  "  
	45$  "  445 >  "  G   6        g  fx1
		g g  fx2		g g  fx3			g g  t		9	]  g  filenamef  rnrs/arithmetic/fixnums.scm
 	 		g	  g  nameg  
fxcopy-bit CFR"8       hh      ]
	4 5$  "  "
	45$  "  
	45$  "  445 >  "  G   6        g  fx1
		g g  fx2		g g  fx3			g g  t		9	]  g  filenamef  rnrs/arithmetic/fixnums.scm
 	 		g	  g  nameg  fxbit-field CER"9      h      ]
	4 5$  "  7
	45$  "  "
	45$  "  
	45$  "  445 >  "  G   6         g  fx1
		~ g  fx2		~ g  fx3			~ g  fx4			~ g  t		N	r  g  filenamef  rnrs/arithmetic/fixnums.scm
 	 		~	  g  nameg  fxcopy-bit-field CDR"   hP      ]

	4 5$  "  
	45$  "  445 >  "  G   C         g  fx1
		N g  fx2		N g  t		$	H  g  filenamef  rnrs/arithmetic/fixnums.scm
 	 		N	  g  nameg  fxarithmetic-shift CCRCiBR"    hP      ]

	4 5$  "  
	45$  "  445 >  "  G   
C       g  fx1
		P g  fx2		P g  t		$	H  g  filenamef  rnrs/arithmetic/fixnums.scm
	 		P	  g  nameg  fxarithmetic-shift-right CAR":  h      ]
	4 5$  "  7
	45$  "  "
	45$  "  
	45$  "  445 >  "  G   6         g  fx1
		~ g  fx2		~ g  fx3			~ g  fx4			~ g  t		N	r  g  filenamef  rnrs/arithmetic/fixnums.scm
	 		~	  g  nameg  fxrotate-bit-field C@R";      hh      ]
	4 5$  "  "
	45$  "  
	45$  "  445 >  "  G   6        g  fx1
		g g  fx2		g g  fx3			g g  t		9	]  g  filenamef  rnrs/arithmetic/fixnums.scm
	 		g	  g  nameg  fxreverse-bit-field C?RC       g  m
		+ g  iface
	2  g  iface
 J g  iface
Q g  iface
j g  iface
q g  iface
 g  iface
 g  iface
! g  i
.P g  n.P g  w
Z  g  filenamef  rnrs/arithmetic/fixnums.scm		
	a		h		i	?	k		n	
	w	E 	M 	U 	] 	e 	m 	u 	} 	 	 	 	
 	g 	 	 	 	 	 	 	 	 	b 	 	! 	"k 	# 	$ 	&- 	'V 	(I 	)& 	*
 	+ 	,D 	-u 	. 	/ 	/ 	0	2M	3	 1	3
   C6 